# Use commit instead of v2.5.0
%global commit dd0382995a30f9f108250e98499072abd354945f
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Summary:        OpenTenBase Database Management System
Name:           OpenTenBase
Version:        2.5.0
Release:        5%{?dist}
License:        BSD-3-Clause
URL:            https://www.opentenbase.org/
%if 0%{?shortcommit:1}
Source0:        https://github.com/OpenTenBase/OpenTenBase/archive/%{commit}/OpenTenBase-%{shortcommit}.tar.gz
%else
Source0:        https://github.com/OpenTenBase/%{name}/archive/refs/tags/v%{version}.tar.gz
%endif

%ifarch loongarch64
Patch3000:      add-loongarch-support.patch
%endif

BuildRequires:  gcc make
BuildRequires:  readline-devel zlib-devel openssl-devel uuid-devel bison flex
BuildRequires:  perl
Requires:       readline zlib openssl-libs uuid
# provides pg* bin, which conflicts with postgresql
Conflicts:      postgresql-server
# provides libecpg.so/libpgtypes.so, which conflicts with libecpg/libpgtypes
Conflicts:      libecpg libpgtypes


%description
OpenTenBase is an advanced enterprise-level database management system based on prior work of 
Postgres-XL project. It supports an extended subset of the SQL standard, including transactions, 
foreign keys, user-defined types and functions. Additional, it adds parallel computing, security, 
management, audit and other functions.

%package devel
Summary: Development files for %{name}
Requires:       %{name} = %{version}-%{release}
# provides ecpg*.h, which conflicts with libecpg
Conflicts:      libecpg-devel

%description devel
This package contains the header files and libraries needed to compile C or C++ applications 
which will directly interact with the OpenTenBase.

%prep
%autosetup -p1 %{?shortcommit:-n %{name}-%{commit}}

%build
export CFLAGS="-g -fPIE -I%{_includedir}/OpenTenBase"
export LDFLAGS="-fPIE -Wl,-rpath,%{_libdir}/OpenTenBase"
export PKG_CONFIG_PATH="%{_libdir}/pkgconfig/OpenTenBase"
%configure --enable-user-switch --with-openssl --with-ossp-uuid --disable-rpath\
           --libdir=%{_libdir}/OpenTenBase \
           --includedir=%{_includedir}/OpenTenBase
# Avoid libpq library file conflicts:--libdir, --includedir
%make_build

%install
%make_install
pushd contrib
# chmod +x pgxc_ctl/make_signature
%make_build
%make_install
popd

# Avoid libpq library file conflicts
mkdir -p %{buildroot}%{_libdir}/pkgconfig/OpenTenBase
mv %{buildroot}%{_libdir}/OpenTenBase/pkgconfig/*.pc %{buildroot}%{_libdir}/pkgconfig/OpenTenBase/

# Avoid libpq bin file conflicts
mkdir -p %{buildroot}%{_libexecdir}
mv %{buildroot}%{_bindir}/pg_config %{buildroot}%{_libexecdir}/

# Avoid libpq share file conflicts
rm -f %{_datadir}/postgresql/pg_service.conf.sample

%files
%license LICENSE.txt
%doc README.md 
%doc %{_docdir}/postgresql/extension/*.example
%{_bindir}/{clusterdb,confmod,create*,drop*,ecpg,gtm*,init*,oid2name}
%{_bindir}/pg_*
%{_bindir}/{pgbench,pgxc_*,postgres,postmaster,psql,reindexdb,vacuum*}
%{_libexecdir}/pg_config
%{_libdir}/OpenTenBase/libecpg.so*
%{_libdir}/OpenTenBase/libecpg_compat.so*
%{_libdir}/OpenTenBase/libpgtypes.so*
%{_libdir}/OpenTenBase/libpq.so*
%{_libdir}/OpenTenBase/postgresql
%{_datadir}/postgresql
%dir %{_includedir}/OpenTenBase/postgresql
%dir %{_libdir}/pkgconfig/OpenTenBase/

%files devel
%{_includedir}/OpenTenBase/*.h
%{_includedir}/OpenTenBase/libpq
%{_includedir}/OpenTenBase/libpq-events.h
%{_includedir}/OpenTenBase/libpq-fe.h
%{_includedir}/OpenTenBase/postgresql
%{_libdir}/OpenTenBase/*.a
%{_libdir}/pkgconfig/OpenTenBase/*.pc

%changelog
* Fri Jun 21 2024 Zhai Liangliang <zhailiangliang@loongson.cn> 2.5.0-5
- [Type] other
- [DESC] add loongarch support

* Mon Mar 11 2024 Wang Guodong <gordonwwang@tencent.com> - 2.5.0-4
- move libpq.so to OpenTenBase

* Tue Nov 7 2023 Wang Guodong <gordonwwang@tencent.com> - 2.5.0-3
- Conflicts with libecpg

* Thu Nov 2 2023 Wang Guodong <gordonwwang@tencent.com> - 2.5.0-2
- Conflicts with libpq, postgresql-server

* Mon Oct 30 2023 Wang Guodong <gordonwwang@tencent.com> - 2.5.0-1
- initial build
